@@ -253,5 +253,5 @@ mediaShow.reAlign = function ()
 $(function(){
     $('.buttonPrev').text("Vorige");
     $('.buttonNext').text("Volgende");
-    $('.portlet-static-2018eenmaal-andermaal-documentatie .portletHeader span').wrap('<a href="http://www.porseleinplaats.nl/algemeen/eenmaal-andermaal-doc/eenmaal-andermaal-doc/"></a>');
+    $('.portlet-static-opening-2018eenmaal-andermaal .portletHeader span').wrap('<a href="http://www.porseleinplaats.nl/algemeen/eenmaal-andermaal-doc/eenmaal-andermaal-doc/"></a>');
 });
\ No newline at end of file
